@@ -71,22 +71,22 @@ extern "C"
  */
   int eXosip_execute (void);
 
-  typedef enum
-  {
-    EXOSIP_OPT_UDP_KEEP_ALIVE = 1,
-    EXOSIP_OPT_UDP_LEARN_PORT = 2,
-    EXOSIP_OPT_SET_HTTP_TUNNEL_PORT = 3,
-    EXOSIP_OPT_SET_HTTP_TUNNEL_PROXY = 4,
-    EXOSIP_OPT_SET_HTTP_OUTBOUND_PROXY = 5,     /* used for http tunnel ONLY */
-    EXOSIP_OPT_DONT_SEND_101 = 6,
-    EXOSIP_OPT_USE_RPORT = 7,
-    EXOSIP_OPT_SET_IPV4_FOR_GATEWAY = 8,
-    EXOSIP_OPT_ADD_DNS_CACHE = 9,
-    EXOSIP_OPT_EVENT_PACKAGE = 10,
-    EXOSIP_OPT_SET_IPV6_FOR_GATEWAY = 11,
-    EXOSIP_OPT_ADD_ACCOUNT_INFO = 12,
-    EXOSIP_OPT_SRV_WITH_NAPTR = 13
-  } eXosip_option;
+#define EXOSIP_OPT_UDP_KEEP_ALIVE 1
+#define EXOSIP_OPT_UDP_LEARN_PORT 2
+#define EXOSIP_OPT_SET_HTTP_TUNNEL_PORT 3
+#define EXOSIP_OPT_SET_HTTP_TUNNEL_PROXY 4
+#define EXOSIP_OPT_SET_HTTP_OUTBOUND_PROXY 5     /* used for http tunnel ONLY */
+#define EXOSIP_OPT_DONT_SEND_101 6
+#define EXOSIP_OPT_USE_RPORT 7
+#define EXOSIP_OPT_SET_IPV4_FOR_GATEWAY 8
+#define EXOSIP_OPT_ADD_DNS_CACHE 9
+#define EXOSIP_OPT_EVENT_PACKAGE 10
+#define EXOSIP_OPT_SET_IPV6_FOR_GATEWAY 11
+#define EXOSIP_OPT_ADD_ACCOUNT_INFO 12
+#define EXOSIP_OPT_DNS_CAPABILITIES 13
+
+  /* obsolete: to be removed */
+#define EXOSIP_OPT_SRV_WITH_NAPTR EXOSIP_OPT_DNS_CAPABILITIES
 
   struct eXosip_dns_cache
   {
@@ -118,7 +118,7 @@ extern "C"
  * @param value   value for options.
  * 
  */
-  int eXosip_set_option (eXosip_option opt, const void *value);
+  int eXosip_set_option (int opt, const void *value);
 
 #ifdef OSIP_MT
 
@@ -239,21 +239,6 @@ extern "C"
 
 #ifndef DOXYGEN
 
-/**
- * Force eXosip to use a specific ip address in all
- * contact and Via headers in SIP message.
- * **PLEASE DO NOT USE: use eXosip_masquerade_contact instead**
- *
- * @param localip 	the ip address.
- *
- * If set to NULL, then the local ip address will be guessed 
- * automatically (returns to default mode).
- *
- * ******LINPHONE specific methods******
- *
- */
-  int eXosip_force_masquerade_contact (const char *localip);
-
 /**
  * Wake Up the eXosip_event_wait method.
  * 
@@ -292,23 +277,6 @@ extern "C"
  */
   int eXosip_guess_localip (int family, char *address, int size);
 
-#ifndef DOXYGEN
-
-/**
- * Find the interface to be used to reach the specified host.
- * 
- * @param ip    a string containing the local IP address.
- * @param localip	the local ip address to be used to reach host.
- *
- * You usually don't need this function at all.
- *
- * ******LINPHONE specific methods******
- *
- */
-  int eXosip_get_localip_for (const char *host, char *localip, int size);
-
-#endif
-
 /** @} */
 
 
