@@ -440,6 +440,27 @@ extern "C"
   */
   eXosip_tls_ctx_error eXosip_set_tls_ctx (eXosip_tls_ctx_t * ctx);
 
+/**
+  *	Select by CN name the server certificate from OS store.
+  *
+  *	12/11/2009 -> implemented only for "Windows Certificate Store"
+  *
+  *	@param local_certificate_cn  CN name of the certificate to send on incoming connection
+  *
+  *	@return  the eXosip_tls_ctx_error code
+  */
+  eXosip_tls_ctx_error eXosip_tls_use_server_certificate (const char *local_certificate_cn);
+
+/**
+  *	Configure to accept/reject self signed and expired certificates.
+  * NOTE: default is to accept (0)
+  *
+  *	@param _tls_verify_client_certificate  ">0": refuse self signed and expired certificates
+  *
+  *	@return  the eXosip_tls_ctx_error code
+  */
+  eXosip_tls_ctx_error eXosip_tls_verify_certificate (int _tls_verify_client_certificate);
+
 /** @} */
 
 #ifdef __cplusplus
